# Chess.com UI/UX Reference

> Populated by the `ux-auditor` agent. Run the agent to fill this document.

## Methodology

<!-- How the analysis was conducted: web research, public pages, user screenshots -->

## Game Review UI

### Board & Layout
### Eval Bar
### Score Chart
### Move List & Classifications
### Engine Lines & Arrows

## Training / Puzzles UI

### Puzzle Interface
### Feedback Mechanism (correct / incorrect)
### Progression & Difficulty

## Navigation & Information Architecture

### Menu Structure
### Mode Switching
### Responsive / Mobile

## Design Language

### Colors & Contrast
### Typography
### Iconography
### Animations & Transitions

## Key Patterns Worth Emulating

<!-- Numbered list: pattern + why it works for ~1000 Elo players -->

## Anti-Patterns to Avoid

<!-- Patterns that don't serve our audience or architecture -->
